@@ -1,6 +1,8 @@
-#' @importFrom parsnip translate
+#' @importFrom parsnip translate check_args
 #' @export
 parsnip::translate
+#' @export
+parsnip::check_args
 #' @importFrom generics min_grid
 #' @export
 generics::min_grid
